@@ -91,6 +91,8 @@ void                   gnome_desktop_thumbnail_factory_create_failed_thumbnail (
 
 
 /* Thumbnailing utils: */
+gboolean   gnome_desktop_thumbnail_has_uri           (GdkPixbuf          *pixbuf,
+						      const char         *uri);
 gboolean   gnome_desktop_thumbnail_is_valid          (GdkPixbuf          *pixbuf,
 						      const char         *uri,
 						      time_t              mtime);
